@@ -1,4 +1,4 @@
-from typing import List, Dict, Any
+from typing import List, Dict, Any, Union
 from csle_common.dao.emulation_config.emulation_env_config import EmulationEnvConfig
 from csle_common.dao.emulation_observation.defender.emulation_defender_machine_observation_state \
     import EmulationDefenderMachineObservationState
@@ -24,7 +24,7 @@ class EmulationDefenderObservationState:
     Represents the defender's agent's current belief state of the emulation
     """
 
-    def __init__(self, kafka_config: KafkaConfig,
+    def __init__(self, kafka_config: Union[KafkaConfig, None],
                  client_population_metrics: ClientPopulationMetrics = None, docker_stats: DockerStats = None,
                  snort_ids_alert_counters: SnortIdsAlertCounters = None,
                  ossec_ids_alert_counters: OSSECIdsAlertCounters = None,
@@ -140,7 +140,7 @@ class EmulationDefenderObservationState:
         """
         try:
             obj = EmulationDefenderObservationState(kafka_config=d["kafka_config"])
-        except:
+        except Exception:
             obj = EmulationDefenderObservationState(kafka_config=None)
         obj.machines = list(map(lambda x: EmulationDefenderMachineObservationState.from_dict(d=x), d["machines"]))
         obj.actions_tried = set(list(map(lambda x: tuple(x), d["actions_tried"])))
